@@ -16,8 +16,6 @@ import calculate
 from ftplib import FTP
 from datetime import date
 from cStringIO import StringIO
-from BeautifulSoup import BeautifulStoneSoup
-from dateutil.parser import parse as dateparse
 
 
 class AP(object):
@@ -81,27 +79,6 @@ class AP(object):
         self.ftp.quit()
         return results
     
-    def get_topofticket(self, election_date, **kwargs):
-        """
-        Takes a date in any common format (YYYY-MM-DD is preferred) 
-        and returns the results for that date.
-        """
-        try:
-            dt = dateparse(election_date)
-        except ValueError:
-            raise ValueError("The election date you've submitted could not be parsed. Try submitting it in YYYY-MM-DD format.")
-        result = TopOfTicket(self, dt.strftime("%Y%m%d"), **kwargs)
-        self.ftp.quit()
-        return result
-    
-    def get_delegate_summary(self):
-        """
-        Return a nationwide summary and state-level totals contain 
-        delegate counts for all the candidates in the presidential 
-        nomination contest held by the two major parties.
-        """
-        return DelegateSummary(self).nominations
-
     #
     # Private methods
     #
@@ -121,11 +98,10 @@ class AP(object):
         try:
             self.ftp.retrbinary(cmd, buffer_.write)
         except Exception, e:
-            if "550 The system cannot find the" in e.message:
+            if "550 The system cannot find the path specified" in e.message:
                 raise FileDoesNotExistError("The file you've requested does not exist." +
                     " If you're looking for data about a state, make sure you" +
-                    " input valid postal codes. If you're looking for a date," +
-                    " make sure it's correct.")
+                    " input valid postal codes.")
             elif "530 User cannot log in" in e.message:
                 raise BadCredentialsError("The username and password you submitted" +
                 " are not accepted by the AP's FTP.")
@@ -227,24 +203,13 @@ class AP(object):
         return list(itertools.izip_longest(*args, fillvalue=fillvalue))
 
 
-#
-# Result collections
-#
-
-class BaseAPResultCollection(object):
+class State(object):
     """
-    Base class that defines the methods to retrieve AP CSV 
-    data and shared properties and methods for State and 
-    TopOfTicket objects.
+    One of these United States.
     
-    Any class that inherits from BaseAPResults must define
-    these paths before it calls the parent __init__:
-        
-        * self.results_file_path
-        * self.delegates_file_path
-        * self.race_file_path
-        * self.reporting_unit_file_path
-        * self.candidate_file_path
+    Returned by the AP client in response to a `get_state` or `get_states`
+    call. Contains, among its attributes, the results for all races recorded
+    by the AP.
     """
     
     def __init__(self, client, name, results=True, delegates=True):
@@ -283,7 +248,7 @@ class BaseAPResultCollection(object):
     @property
     def races(self):
         """
-        Returns a list of all the races reporting results.
+        Returns a list of all the races reporting results in this state.
         """
         return self._races.values()
 
@@ -310,6 +275,7 @@ class BaseAPResultCollection(object):
         for k in kwargs.keys():
             races = filter(lambda x: getattr(x, k) == kwargs[k], races)
         return races
+        
 
     @property
     def reporting_units(self):
@@ -330,9 +296,7 @@ class BaseAPResultCollection(object):
     @property
     def counties(self):
         """
-        Gets all reporting units that can be defined as counties (read: !states).
-        Also does a crosswalk to aggregate New England ReportingUnits into their
-        respective counties. 
+        Gets all reporting units that can be defined as counties.
         """
         # Filter out the state level data
         ru_list = [o for o in self.reporting_units if o.fips and not o.is_state]
@@ -385,7 +349,7 @@ class BaseAPResultCollection(object):
         Download the state's candidate file and load the data.
         """
         # Fetch the data from the FTP
-        candidate_list = self.client._fetch_csv(self.candidate_file_path)
+        candidate_list = self.client._fetch_csv("/inits/%(name)s/%(name)s_pol.txt" % self.__dict__)
         # Loop through it...
         for cand in candidate_list:
             # Create a Candidate...
@@ -409,7 +373,7 @@ class BaseAPResultCollection(object):
         Download all the races in the state and load the data.
         """
         # Get the data
-        race_list = self.client._fetch_csv(self.race_file_path)
+        race_list = self.client._fetch_csv("/inits/%(name)s/%(name)s_race.txt" % self.__dict__)
         # Loop through it all
         for race in race_list:
             # Create a Race object...
@@ -421,7 +385,6 @@ class BaseAPResultCollection(object):
                 race_type = race['race_id'],
                 seat_name = race['se_name'],
                 seat_number = race['se_number'],
-                state_postal = race.get('st_postal', None),
                 scope = race['of_scope'],
                 date = date(*map(int, [race['el_date'][:4], race['el_date'][4:6], race['el_date'][6:]])),
                 num_winners = int(race['ra_num_winners']),
@@ -436,15 +399,11 @@ class BaseAPResultCollection(object):
         Download all the reporting units and load the data.
         """
         # Get the data
-        ru_list = self.client._fetch_csv(self.reporting_unit_file_path)
+        ru_list = self.client._fetch_csv("/inits/%(name)s/%(name)s_ru.txt" % self.__dict__)
         # Loop through them all
         for r in ru_list:
-            # if `st_postal` is in the dict, we're getting Top of the Ticket data,
-            # so we want to put reportingunits in the state they belong to.
-            # otherwise stuff the RUs into all of the races, as they're all in the same state.
-            races = self.filter_races(state_postal=r.get('st_postal', None)) or self.races
             # Create ReportingUnit objects for each race
-            for race in races:
+            for race in self.races:
                 ru = ReportingUnit(
                     name = r['ru_name'],
                     ap_number = r['ru_number'],
@@ -454,7 +413,7 @@ class BaseAPResultCollection(object):
                     num_reg_voters = int(r['ru_reg_voters']),
                 )
                 # And add them to the global store
-                race._reporting_units.update({ru.key: ru})
+                race._reporting_units.update({ru.ap_number: ru})
             # We add a set of reportingunits for the State object
             # so you can get county and state voter info from the
             # State object itself. 
@@ -466,7 +425,7 @@ class BaseAPResultCollection(object):
                 precincts_total = int(r['ru_precincts']),
                 num_reg_voters = int(r['ru_reg_voters']),
             )
-            self._reporting_units.update({ru.key: ru})
+            self._reporting_units.update({ru.ap_number: ru})
     
     def _get_flat_delegates(self):
         """
@@ -474,7 +433,7 @@ class BaseAPResultCollection(object):
         """
         # Pull the data
         flat_list = self.client._fetch_flatfile(
-            self.delegates_file_path,
+            "/%(name)s/flat/%(name)s_D.txt" % self.__dict__,
             [ # First the basic fields that will the same in each row
                 'test',
                 'election_date',
@@ -534,7 +493,7 @@ class BaseAPResultCollection(object):
         """
         # Download the data
         flat_list = self.client._fetch_flatfile(
-            self.results_file_path,
+            "/%(name)s/flat/%(name)s.txt" % self.__dict__,
             [ # First the basic fields that will the same in each row
                 'test',
                 'election_date',
@@ -595,7 +554,8 @@ class BaseAPResultCollection(object):
 #                    fips = '0' + fips
             
             # Pull the reporting unit
-            reporting_unit = race.get_reporting_unit("%s%s" % (row['county_name'], county_number))
+            reporting_unit = race.get_reporting_unit(county_number)
+            
             # Loop through all the candidates
             votes_cast = 0
             for cand in row['candidates']:
@@ -652,178 +612,6 @@ class BaseAPResultCollection(object):
                     votes_cast
                 )
 
-class State(BaseAPResultCollection):
-    """
-    One of these United States.
-    
-    Returned by the AP client in response to a `get_state` or `get_states`
-    call. Contains, among its attributes, the results for all races recorded
-    by the AP.
-    """
-
-    def __init__(self, client, name, results=True, delegates=True):
-        self.results_file_path = "/%(name)s/flat/%(name)s.txt" % {'name': name}
-        self.delegates_file_path = "/%(name)s/flat/%(name)s_D.txt" % {'name': name}
-        self.race_file_path = "/inits/%(name)s/%(name)s_race.txt" % {'name': name}
-        self.reporting_unit_file_path = "/inits/%(name)s/%(name)s_ru.txt" % {'name': name}
-        self.candidate_file_path = "/inits/%(name)s/%(name)s_pol.txt" % {'name': name}
-        super(State, self).__init__(client, name, results, delegates)
-
-
-class TopOfTicket(BaseAPResultCollection):
-    """
-    These United States.
-    
-    Returned by the AP client in response to a `get_topofticket`
-    call. Contains, among its attributes, the results for all races recorded
-    by the AP.
-    """
-    def __init__(self, client, name, results=True, delegates=True):
-        self.results_file_path = "/Delegate_Tracking/US/flat/US_%(name)s.txt" % {'name': name}
-        self.delegates_file_path = "/Delegate_Tracking/US/flat/US_%(name)s_d.txt" % {'name': name}
-        self.race_file_path = "/inits/US/US_%(name)s_race.txt" % {'name': name}
-        self.reporting_unit_file_path = "/inits/US/US_%(name)s_ru.txt" % {'name': name}
-        self.candidate_file_path = "/inits/US/US_%(name)s_pol.txt" % {'name': name}
-        super(TopOfTicket, self).__init__(client, name, results, delegates)
-    
-    @property
-    def states(self):
-        return [o for o in self._reporting_units.values() if o.is_state]
-
-
-class DelegateSummary(object):
-    """
-    A result collection that contains a summary of delegates won by candidates
-    seeking a party's presidential nomination.
-    """
-    summary_file_path = "Delegate_Tracking/Reports/delsum.xml"
-    state_file_path = "Delegate_Tracking/Reports/delstate.xml"
-    
-    def __init__(self, client):
-        self.client = client
-        self.nominations = []
-        self.fetch()
-    
-    def __unicode__(self):
-        return unicode(self.name)
-    
-    def __str__(self):
-        return self.__unicode__().encode("utf-8")
-     
-    def __repr__(self):
-        return '<%s: %s>' % (self.__class__.__name__, self.__unicode__())
-    
-    def fetch(self):
-        # Pull the nationwide summary file
-        summary = self.client._fetch(self.summary_file_path)
-        summarysoup = BeautifulStoneSoup(summary)
-        # Pull the state-by-state summary file
-        states = self.client._fetch(self.state_file_path)
-        statesoup = BeautifulStoneSoup(states)
-        # Loop through the parties in the nationwide summary
-        for party in summarysoup.find("delsum").findAll("del"):
-            # Create a nomination object for each
-            nom = Nomination(
-                party = party['pid'],
-                delegates_needed = int(party['dneed']),
-                delegates_total = int(party['dvotes']),
-                delegates_chosen = int(party['dchosen']),
-            )
-            # Loop through the nationwide totals for each candidate
-            for cand in party.findAll("cand"):
-                # And create a candidate object with that nationwide total
-                cand_obj = Candidate(
-                    ap_natl_number = cand['cid'],
-                    last_name = cand['cname'],
-                    delegates = int(cand['dtot'])
-                )
-                nom._candidates.append(cand_obj)
-            # Loop through the state data
-            for stateparty in statesoup.find("delstate").findAll("del"):
-                # If the party matches our current nationwide loop...
-                if stateparty['pid'] == party['pid']:
-                    # Then loop through all the states
-                    for state in stateparty.findAll("state"):
-                        state_obj = StateDelegation(
-                            name = state['sid'],
-                        )
-                        # Now loop through the candidates in this state
-                        for statecand in state.findAll("cand"):
-                            cand_obj = Candidate(
-                                ap_natl_number = statecand['cid'],
-                                last_name = statecand['cname'],
-                                delegates = int(statecand['dtot'])
-                            )
-                            state_obj._candidates.append(cand_obj)
-                        nom._states.append(state_obj)
-            # Add the nomination to our finished list now that it's got data
-            self.nominations.append(nom)
-
-#
-# Delegate result objects
-#
-
-class Nomination(object):
-    """
-    A contest to be the presidential nominee of one of the two major parties.
-    
-    Results are determined by delegates, not by votes.
-    """
-    def __init__(self, party, delegates_needed, delegates_total, delegates_chosen):
-        self.party = party
-        self.delegates_needed = delegates_needed
-        self.delegates_total = delegates_total
-        self.delegates_chosen = delegates_chosen
-        self.delegates_chosen_percent = calculate.percentage(
-            delegates_chosen,
-            delegates_total
-        )
-        self._candidates = []
-        self._states = []
-    
-    def __unicode__(self):
-        return unicode(self.party)
-    
-    def __str__(self):
-        return self.__unicode__().encode("utf-8")
-    
-    def __repr__(self):
-        return '<%s: %s>' % (self.__class__.__name__, self.__unicode__())
-    
-    @property
-    def candidates(self):
-        return sorted(self._candidates, key=lambda x: x.delegates, reverse=True)
-    
-    @property
-    def states(self):
-        return sorted(self._states, key=lambda x: x.name)
-
-
-class StateDelegation(object):
-    """
-    A state's delegation and who they choose to be a party's presidential nominee.
-    """
-    def __init__(self, name):
-        self.name = name
-        self._candidates = []
-    
-    def __unicode__(self):
-        return unicode(self.name)
-    
-    def __str__(self):
-        return self.__unicode__().encode("utf-8")
-    
-    def __repr__(self):
-        return '<%s: %s>' % (self.__class__.__name__, self.__unicode__())
-    
-    @property
-    def candidates(self):
-        return sorted(self._candidates, key=lambda x: x.delegates, reverse=True)
-
-
-#
-# Election result objects
-#
 
 class Race(object):
     """
@@ -841,12 +629,11 @@ class Race(object):
         'R': 'GOP Primary',
         'G': 'General Election',
         'E': 'Dem Caucus',
-        'S': 'GOP Caucus',
-        'L': 'Libertarian', # Not documented by the AP, but that's what it appears to be.
+        'S': 'GOP Caucus'
     }
 
     def __init__(self, ap_race_number=None, office_name=None, office_description=None,
-                 office_id=None, seat_name=None, seat_number=None, state_postal=None, scope=None,
+                 office_id=None, seat_name=None, seat_number=None, scope=None,
                  date=None, num_winners=None, race_type=None, party=None, uncontested=None,
                  precincts_total=None, precincts_reporting=None,
                  precincts_reporting_percent=None, votes_cast=None):
@@ -856,7 +643,6 @@ class Race(object):
         self.office_id = office_id
         self.seat_name = seat_name
         self.seat_number = seat_number
-        self.state_postal = state_postal
         self.scope = scope
         self.date = date
         self.num_winners = num_winners
@@ -945,7 +731,7 @@ class Race(object):
             for ru in ru_list:
                 try:
                     d[ru.fips].append(ru)
-                except KeyError:
+                except:
                     d[ru.fips] = [ru]
             county_list = []
             for county, units in d.items():
@@ -969,7 +755,7 @@ class Race(object):
                     for result in unit.results:
                         try:
                             cands[result.candidate.ap_polra_number].append(result)
-                        except KeyError:
+                        except:
                             cands[result.candidate.ap_polra_number] = [result]
                 for ap_polra_number, results in cands.items():
                     combined = Result(
@@ -1041,10 +827,6 @@ class ReportingUnit(object):
     
     def __repr__(self):
         return '<%s: %s>' % (self.__class__.__name__, self.__unicode__())
-
-    @property
-    def key(self):
-        return "%(name)s%(ap_number)s" % self.__dict__
     
     @property
     def results(self):
@@ -1053,7 +835,7 @@ class ReportingUnit(object):
         
         If no votes are in, it returns the candidates in alphabetical order.
         """
-        if self.votes_cast:
+        if self.precincts_reporting:
             return sorted(self._results.values(), key=lambda x: x.vote_total,
                 reverse=True)
         else:
@@ -1106,7 +888,7 @@ class Candidate(object):
     @property
     def name(self):
         if not self.last_name in ('Yes', 'No'):
-            s = " ".join([i for i in [self.first_name, self.last_name] if i])
+            s = u'%s %s' % (self.first_name, self.last_name)
             return s.strip()
         else:
             return u'%s' % self.last_name
@@ -1170,22 +952,6 @@ COUNTY_CROSSWALK = {
         '33015': 'Rockingham',
         '33017': 'Strafford',
         '33019': 'Sullivan',
-    },
-    'VT': {
-        '50001': 'Addison',
-        '50003': 'Bennington',
-        '50005': 'Caledonia',
-        '50007': 'Chittenden',
-        '50009': 'Essex',
-        '50011': 'Franklin',
-        '50013': 'Grand Isle',
-        '50015': 'Lamoille',
-        '50017': 'Orange',
-        '50019': 'Orleans',
-        '50021': 'Rutland',
-        '50023': 'Washington',
-        '50025': 'Windham',
-        '50027': 'Windsor',
     }
 }
 
